@@ -18,7 +18,7 @@ rqda.formula <- function(formula, data, ...)
         cat("There is no data set.\n\n")
         return(output)
     }
-    if(class(data) != "data.frame") 
+    if(!inherits(data, "data.frame"))
     {
         cat("data parameter is not a data.frame.\n\n")
         return(output)
@@ -78,7 +78,7 @@ function(x, grouping, subset = NULL, resmatrix = NULL, restext = NULL,
         cat("grouping vector is missing.\n\n")
         return(output)
     }
-    if(class(x) != "data.frame")
+    if(!inherits(x, "data.frame"))
     {
         cat("data set parameter is not a data.frame.\n\n")
         return(output)
@@ -188,7 +188,7 @@ function(object, newdata, prior=object$prior, gamma = object$gamma, grouping = N
         cat("newdata is missing.\n\n")
         return(output)
     }
-    if(class(newdata) != "data.frame")
+    if(!inherits(newdata, "data.frame"))
     {
         cat("newdata parameter is not a data.frame.\n\n")
         return(output)
@@ -200,7 +200,7 @@ function(object, newdata, prior=object$prior, gamma = object$gamma, grouping = N
     }
     if(!is.null(grouping))
     {
-        if(class(grouping) == "factor")
+        if(inherits(grouping, "factor"))
         {
             if(sum(suppressWarnings(is.na(as.numeric(levels(grouping))))) > 0)
             {
